OC.L10N.register(
    "files",
    {
    "File could not be found" : "El archivo no se ha encontrado",
    "Move or copy" : "Mover o copiar",
    "Download" : "Descargar",
    "Delete" : "Eliminar",
    "Tags" : "Etiquetas",
    "Show list view" : "Mostrar vista de lista",
    "Show grid view" : "Mostrar vista de cuadrícula",
    "Home" : "Inicio",
    "Close" : "Cerrar",
    "Could not create folder \"{dir}\"" : "No se pudo crear la carpeta \"{dir}\"",
    "This will stop your current uploads." : "Esto detendrá las subidas en curso.",
    "Upload cancelled." : "Subida cancelada.",
    "Processing files …" : "Procesando archivos …",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "No ha sido posible subir {filename} porque es un directorio o tiene 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "No hay suficiente espacio libre. Quiere subir {size1} pero solo quedan {size2}",
    "Target folder \"{dir}\" does not exist any more" : "La carpeta de destino \"{dir}\" ya no existe",
    "Not enough free space" : "No hay espacio libre suficiente",
    "An unknown error has occurred" : "Ha ocurrido un error desconocido",
    "File could not be uploaded" : "No se ha podido subir el archivo",
    "Uploading …" : "Subiendo …",
    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
    "Uploading … ({currentNumber}/{total})" : "Cargando… ({currentNumber}/{total})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Subir este archivo no es compatible",
    "Target folder does not exist any more" : "La carpeta destino ya no existe",
    "Operation is blocked by access control" : "Esta operación está bloqueada por el control de accesos",
    "Error when assembling chunks, status code {status}" : "Error al reunir los trozos, código de estado {status}",
    "Actions" : "Acciones",
    "Rename" : "Renombrar",
    "Move" : "Mover",
    "Copy" : "Copiar",
    "Choose target folder" : "Elegir carpeta de destino",
    "Set reminder" : "Establecer recordatorio",
    "Edit locally" : "Editar localmente",
    "Open" : "Abrir",
    "_Delete file_::_Delete files_" : ["Eliminar archivo","Eliminar archivos","Eliminar archivos"],
    "_Delete folder_::_Delete folders_" : ["Eliminar carpeta","Eliminar carpetas","Eliminar carpetas"],
    "_Disconnect storage_::_Disconnect storages_" : ["Desconectar almacenamiento","Desconectar almacenamientos","Desconectar almacenamientos"],
    "_Leave this share_::_Leave these shares_" : ["Abandonar este recurso compartido","Abandonar estos recursos compartidos","Abandonar estos recursos compartidos"],
    "Could not load info for file \"{file}\"" : "No se ha podido cargar información para el archivo \"{file}\"",
    "Files" : "Archivos",
    "Details" : "Detalles",
    "Please select tag(s) to add to the selection" : "Seleccione la(s) etiqueta(s) para añadir a la selección",
    "Apply tag(s) to selection" : "Aplicar etiqueta(s) a la selección",
    "Select directory \"{dirName}\"" : "Seleccione la carpeta \"{dirName}\"",
    "Select file \"{fileName}\"" : "Seleccione el archivo \"{fileName}\"",
    "Pending" : "Pendiente",
    "Unable to determine date" : "No se ha podido determinar la fecha",
    "This operation is forbidden" : "Esta operación está prohibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Esta carpeta no está disponible, por favor verifique los registros o contacte con el administrador",
    "Storage is temporarily not available" : "El almacenamiento no está disponible temporalmente",
    "Could not move \"{file}\", target exists" : "No se pudo mover \"{file}\", ya existe",
    "Could not move \"{file}\"" : "No se pudo mover \"{file}\"",
    "copy" : "copiar",
    "Could not copy \"{file}\", target exists" : "No se ha podido copiar \"{file}\", ya existe el destino",
    "Could not copy \"{file}\"" : "No se ha podido copiar \"{file}\"",
    "Copied {origin} inside {destination}" : "Se ha copiado {origin} dentro de {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Se han copiado {origin} y {nbfiles} otros archivos dentro de {destination}",
    "Failed to redirect to client" : "Fallo al redirigir al cliente",
    "{newName} already exists" : "{newName} ya existe",
    "Could not rename \"{fileName}\", it does not exist any more" : "No se pudo renombrar \"{fileName}\", ya no existe",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "El nombre \"{targetName}\" ya está en uso en la carpeta \"{dir}\". Por favor elija un nombre diferente.",
    "Could not rename \"{fileName}\"" : "No se pudo renombrar \"{fileName}\"",
    "Could not create file \"{file}\"" : "No se pudo crear archivo \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "No se pudo crear archivo \"{file}\" porque ya existe",
    "Could not create folder \"{dir}\" because it already exists" : "No se ha podido crear la carpeta \"{dir}\" porque ya existe",
    "Could not fetch file details \"{file}\"" : "No se pudieron obtener los detalles de \"{file}\"",
    "Error deleting file \"{fileName}\"." : "Error al borrar el archivo \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "No hay resultados de búsqueda en otras carpetas para  {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Escriba más de dos caracteres para buscar en otras carpetas",
    "Name" : "Nombre",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetas","%n carpetas"],
    "_%n file_::_%n files_" : ["%n archivo","%n archivos","%n archivos"],
    "{dirs} and {files}" : "{dirs} y {files}",
    "_including %n hidden_::_including %n hidden_" : ["incluyendo %n oculto","incluyendo %n ocultos","incluyendo %n ocultos"],
    "You do not have permission to upload or create files here" : "No tiene permiso para subir o crear archivos aquí",
    "_Uploading %n file_::_Uploading %n files_" : ["Subiendo %n archivo","Subiendo %n archivos","Subiendo %n archivos"],
    "New" : "Nuevo",
    "New file/folder menu" : "Menú de carpeta/archivo nuevo",
    "Select file range" : "Seleccionar el rango de archivos",
    "{used}%" : "{used}%",
    "{used} of {quota} used" : "{used} usados de {quota}",
    "{used} used" : "{used} usados",
    "\"{name}\" is an invalid file name." : "\"{name}\" es un nombre de archivo inválido.",
    "File name cannot be empty." : "El nombre de archivo no puede estar vacío.",
    "\"/\" is not allowed inside a file name." : "\"/\" no se permite en un nombre de archivo.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" no es un tipo de archivo permitido",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "El almacenamiento de {owner} está lleno. ¡No se puede actualizar o sincronizar ningún archivo más!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "La carpeta de grupo \"{mountPoint}\" está llena. ¡No se puede actualizar o sincronizar ningún archivo más!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "El almacenamiento externo \"{mountPoint}\" está lleno. ¡No se puede actualizar o sincronizar ningún archivo más!",
    "Your storage is full, files cannot be updated or synced anymore!" : "Tu almacenamiento está lleno. ¡No se puede actualizar o sincronizar ningún archivo más!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "El almacenamiento de {owner} está casi lleno ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "La carpeta de grupo \"{mountPoint}\" está casi llena ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "El almacenamiento externo \"{mountPoint}\" está casi lleno ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Tu almacenamiento está casi lleno ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["coinciden \"{filter}\"","coincide \"{filter}\"","coincide \"{filter}\""],
    "View in folder" : "Ver en carpeta",
    "Direct link was copied (only works for people who have access to this file/folder)" : "El enlace directo fue copiado (solo funciona para usuarios que tienen acceso a este archivo/carpeta)",
    "Path" : "Ruta",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes","%n bytes"],
    "Favorited" : "Agregado a favoritos",
    "Favorite" : "Favorito",
    "Copy direct link (only works for people who have access to this file/folder)" : "El enlace directo fue copiado (solo funciona para usuarios que tienen acceso a este archivo/carpeta)",
    "New folder" : "Nueva carpeta",
    "Create new folder" : "Crear carpeta nueva",
    "Upload file" : "Subir archivo",
    "Recent" : "Reciente",
    "Not favorited" : "Quitado como favorito",
    "Remove from favorites" : "Quitar de favoritos",
    "Add to favorites" : "Añadir a favoritos",
    "An error occurred while trying to update the tags" : "Se produjo un error al tratar de actualizar las etiquetas",
    "Added to favorites" : "Agregado a favoritos",
    "Removed from favorites" : "Quitado de favoritos",
    "You added {file} to your favorites" : "Has agregado {file} a tus favoritos",
    "You removed {file} from your favorites" : "Has quitado {file} de tus favoritos",
    "Favorites" : "Favoritos",
    "File changes" : "Cambios del archivo",
    "Created by {user}" : "Creado por {user}",
    "Changed by {user}" : "Modificado por {user}",
    "Deleted by {user}" : "Borrado por {user}",
    "Restored by {user}" : "Restaurado por {user}",
    "Renamed by {user}" : "Renombrado por {user}",
    "Moved by {user}" : "Movido por {user}",
    "\"remote account\"" : "\"cuenta remota\"",
    "You created {file}" : "Ha creado {file}",
    "You created an encrypted file in {file}" : "Has creado un archivo cifrado en {file}",
    "{user} created {file}" : "{user} ha creado {file}",
    "{user} created an encrypted file in {file}" : "{user} ha creado un archivo cifrado en {file}",
    "{file} was created in a public folder" : "{file} se ha creado en una carpeta pública",
    "You changed {file}" : "Has cambiado {file}",
    "You changed an encrypted file in {file}" : "Has modificado un archivo cifrado en {file}",
    "{user} changed {file}" : "{user} ha cambiado {file}",
    "{user} changed an encrypted file in {file}" : "{user} ha modificado un archivo cifrado en {file}",
    "You deleted {file}" : "Has borrado {file}",
    "You deleted an encrypted file in {file}" : "Has borrado un archivo cifrado en {file}",
    "{user} deleted {file}" : "{user} eliminó {file}",
    "{user} deleted an encrypted file in {file}" : "{user} ha borrado un archivo cifrado en {file}",
    "You restored {file}" : "Has restaurado {file}",
    "{user} restored {file}" : "{user} restauró {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Has renombrado {oldfile} (oculto) a {newfile} (oculto)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Has renombrado {oldfile} (oculto) a {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Has renombrado {oldfile} a {newfile} (oculto)",
    "You renamed {oldfile} to {newfile}" : "Has renombrado {oldfile} a {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} renombró {oldfile} (oculto) a {newfile} (oculto)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} renombró {oldfile} (oculto) a {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} renombró {oldfile} a {newfile} (oculto)",
    "{user} renamed {oldfile} to {newfile}" : "{user} ha renombrado {oldfile} a {newfile}",
    "You moved {oldfile} to {newfile}" : "Has movido {oldfile} a {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} movió {oldfile} a {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Un archivo fue agregado o borrado de tus <strong>favoritos</strong>",
    "A file or folder has been <strong>changed</strong>" : "Se ha <strong>modificado</strong> un archivo o carpeta",
    "A favorite file or folder has been <strong>changed</strong>" : "Un archivo o carpeta favorito ha sido <strong>cambiado</strong>",
    "Upload (max. %s)" : "Subida (máx. %s)",
    "Accept" : "Aceptar",
    "Reject" : "Rechazar",
    "Incoming ownership transfer from {user}" : "Ha llegado una transferencia de propiedad de {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "¿Deseas aceptar {path}?\n\nNota: El proceso de transferencia tras aceptar podría tardar hasta 1 hora.",
    "Ownership transfer failed" : "Fallo al transferir la propiedad",
    "Your ownership transfer of {path} to {user} failed." : "Ha fallado tu transferencia de propiedad de {path} a {user}.",
    "The ownership transfer of {path} from {user} failed." : "Ha fallado la transferencia de propiedad de {path} desde {user}.",
    "Ownership transfer done" : "Transferencia de propiedad realizada",
    "Your ownership transfer of {path} to {user} has completed." : "Se ha completado su transferencia de propiedad de {path} a {user}.",
    "The ownership transfer of {path} from {user} has completed." : "Se ha completado la transferencia de propiedad de {path} a {user}.",
    "in %s" : "en %s",
    "File Management" : "Gestión de archivos",
    "Current directory path" : "Dirección de la carpeta actual",
    "Reload current directory" : "Recargar carpeta actual",
    "Go to the \"{dir}\" directory" : "Ir a la carpeta \"{dir}\"",
    "Drag and drop files here to upload" : "Arrastre y suelte archivos aquí para subirlos",
    "Your have used your space quota and cannot upload files anymore" : "Ha utilizado su cuota de espacio y ya no puede subir más archivos",
    "You don’t have permission to upload or create files here" : "No tiene permisos para subir o crear archivos aquí",
    "Some files could not be uploaded" : "No se pudieron subir algunos archivos",
    "Files uploaded successfully" : "Se subieron los archivos exitosamente",
    "\"{displayName}\" action executed successfully" : "la acción \"{displayName}\" se ejecutó exitósamente",
    "\"{displayName}\" action failed" : "la acción \"{displayName}\" falló",
    "Toggle selection for file \"{displayName}\"" : "Alternar selección para archivo \"{displayName}\"",
    "Toggle selection for folder \"{displayName}\"" : "Alternar selección para la carpeta \"{displayName}\"",
    "Rename file" : "Renombrar archivo",
    "File name" : "Nombre del archivo",
    "Folder name" : "Nombre de la carpeta",
    "This node is unavailable" : "Este nodo no está disponible",
    "Download file {name}" : "Descargar archivo {name}",
    "\"{name}\" is not an allowed filetype." : "\"{name}\" no es un tipo de archivo permitido.",
    "{newName} already exists." : "{newName} ya existe.",
    "\"{char}\" is not allowed inside a file name." : "\"{char}\" no está permitido dentro del nombre de un archivo.",
    "Name cannot be empty" : "El nombre no puede estar vacío",
    "Another entry with the same name already exists" : "Ya existe otra entrada con el mismo nombre",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Renombrado \"{oldName}\" a \"{newName}\"",
    "Could not rename \"{oldName}\", it does not exist any more" : "No se ha podido renombrar \"{oldName}\", ya no existe",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "El nombre \"{newName}\" ya está en uso en la carpeta \"{dir}\". Por favor, escoja un nombre diferente.",
    "Could not rename \"{oldName}\"" : "No se ha podido renombrar \"{oldName}\"",
    "Total rows summary" : "Resumen de filas totales",
    "Toggle selection for all files and folders" : "Seleccionar/deseleccionar todos los archivos y carpetas",
    "\"{displayName}\" failed on some elements " : "\"{displayName}\" fallo en algunos elementos",
    "\"{displayName}\" batch action executed successfully" : "la acción en lotes \"{displayName}\" se ejecutó exitósamente",
    "List of files and folders." : "Lista de archivos y carpetas.",
    "Column headers with buttons are sortable." : "Las columnas con botones en la cabecera son ordenables.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Esta lista no se muestra completamente por motivos de rendimiento. Los archivos se mostrarán a medida que navega por la lista.",
    "File not found" : "No se ha encontrado el archivo",
    "Storage informations" : "Informaciones de almacenamiento",
    "{usedQuotaByte} used" : "{usedQuotaByte} utilizados",
    "{relative}% used" : "{relative}% utilizado",
    "Could not refresh storage stats" : "No fue posible refrescar las estadísticas de almacenamiento",
    "Your storage is full, files can not be updated or synced anymore!" : "Su almacenamiento está lleno, ¡Ya no se pueden subir ni sincronizarse más archivos!",
    "Create" : "Crear",
    "A file or folder with that name already exists." : "Un archivo o carpeta con ese nombre ya existe.",
    "Transfer ownership of a file or folder" : "Transferir la propiedad de un archivo o carpeta",
    "Choose file or folder to transfer" : "Elegir archivo o carpeta para transferir",
    "Change" : "Cambiar",
    "New owner" : "Nuevo propietario",
    "Choose a file or folder to transfer" : "Elegir un archivo o carpeta para transferir",
    "Transfer" : "Transferir",
    "Transfer {path} to {userid}" : "Transferir {path} a {userid}",
    "Invalid path selected" : "Ruta de archivo seleccionada no válida.",
    "Unknown error" : "Error desconocido",
    "Ownership transfer request sent" : "Enviada la solicitud de transferencia de propiedad",
    "Cannot transfer ownership of a file or folder you do not own" : "No puede transferir la propiedad de un archivo o carpeta de la cual no es propietario",
    "Select file or folder to link to" : "Selecciona archivo o carpeta a enlazar",
    "Choose file" : "Elegir archivo",
    "Choose {file}" : "Seleccionar {file}",
    "Loading current folder" : "Cargando carpeta actual",
    "No files in here" : "Aquí no hay archivos",
    "Upload some content or sync with your devices!" : "¡Suba contenidos o sincronice sus dispositivos!",
    "Go to the previous folder" : "Ir a la carpeta anterior",
    "Go back" : "Ir atrás",
    "Share" : "Compartir",
    "Shared by link" : "Compartido por enlace",
    "Shared" : "Compartido",
    "Switch to list view" : "Cambiar a vista de lista",
    "Switch to grid view" : "Cambiar a vista de cuadrícula",
    "Error during upload: {message}" : "Error durante la subida: {message}",
    "Error during upload, status code {status}" : "Error durante la subida, código de estado {status}",
    "Unknown error during upload" : "Error desconocido durante la subida",
    "Open the files app settings" : "Abrir la configuración de la app Archivos",
    "Files settings" : "Configuración de archivos",
    "File cannot be accessed" : "El archivo no puede ser accesado",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "El archivo no fue encontrado o no tiene permisos para verlo. Solicite al remitente que lo comparta.",
    "Sort favorites first" : "Ordenar los favoritos primero",
    "Sort folders before files" : "Ordenar carpetas antes que archivos",
    "Show hidden files" : "Mostrar archivos ocultos",
    "Crop image previews" : "Recortar la previsualización de las imágenes",
    "Enable the grid view" : "Habilitar vista de cuadrícula",
    "Additional settings" : "Ajustes adicionales",
    "WebDAV" : "WebDAV",
    "WebDAV URL" : "WebDAV URL",
    "Copy to clipboard" : "Copiar al portapapeles",
    "Use this address to access your Files via WebDAV" : "Use esta dirección para acceder a tus archivos vía WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Si ha habilitado 2FA, debe crear y utilizar una nueva contraseña de aplicación haciendo clic aquí.",
    "Clipboard is not available" : "El portapapeles no está disponible",
    "WebDAV URL copied to clipboard" : "El URL Webdav URL fue copiado al portapapeles",
    "Unable to change the favourite state of the file" : "No se ha podido cambiar el estado de favorito del fichero",
    "Error while loading the file data" : "Error al cargar los datos del archivo",
    "Pick a template for {name}" : "Elija una plantilla para {name}",
    "Create a new file with the selected template" : "Crear un nuevo archivo con la plantilla seleccionada",
    "Creating file" : "Creando el archivo",
    "Blank" : "Vacío",
    "Unable to create new file from template" : "No se ha podido crear un nuevo archivo desde la plantilla",
    "Delete permanently" : "Eliminar de forma permanente",
    "Delete and unshare" : "Eliminar y dejar de compartir",
    "You are about to delete {count} items." : "Está a punto de eliminar {count} ítems.",
    "Confirm deletion" : "Confirmar eliminación",
    "Cancel" : "Cancelar",
    "Deletion cancelled" : "Eliminación cancelada",
    "Destination is not a folder" : "El destino no es una carpeta",
    "This file/folder is already in that directory" : "Este archivo/carpeta ya está en ese directorio",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "No puede mover un archivo/carpeta a sí mismo o a una sub-carpeta de sí mismo",
    "(copy)" : "(copiar)",
    "(copy %n)" : "(copiar %n)",
    "Move cancelled" : "Se canceló la movida",
    "A file or folder with that name already exists in this folder" : "Un archivo o carpeta con ese nombre ya existe en esta carpeta",
    "The file does not exist anymore" : "El archivo ya no existe",
    "Choose destination" : "Elegir destino",
    "Copy to {target}" : "Copiar a {target}",
    "Move to {target}" : "Mover a {target}",
    "Cancelled move or copy operation" : "Se canceló la operación de mover o copiar",
    "Move or copy operation failed" : "La operación de mover o copiar falló",
    "Open folder {displayName}" : "Abrir carpeta {displayName}",
    "Open in Files" : "Abrir en Archivos",
    "Open details" : "Abrir detalles",
    "An error occurred while uploading. Please try again later." : "Ocurrió un error mientras se hacía la subida. Por favor, inténtelo de nuevo más tarde.",
    "Could not copy {file}. {message}" : "No se pudo copiar {file}. {message}",
    "Could not move {file}. {message}" : "No se pudo mover {file}. {message}",
    "Created new folder \"{name}\"" : "Se creó la carpeta nueva \"{name}\"",
    "Filename" : "Nombre de archivo",
    "Unable to initialize the templates directory" : "No se ha podido iniciar la carpeta de plantillas",
    "Create new templates folder" : "Crear nueva carpeta de plantillas",
    "Templates" : "Plantillas",
    "New template folder" : "Nueva carpeta de plantillas",
    "One of the dropped files could not be processed" : "Uno de los archivos arrastrados no puede ser procesado",
    "Uploading \"{filename}\" failed" : "La subida de \"{filename}\" falló",
    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} carpeta","{folderCount} carpetas","{folderCount} carpetas"],
    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} archivo","{fileCount} archivos","{fileCount} archivos"],
    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 archivo y {folderCount} carpeta","1 archivo y {folderCount} carpetas","1 archivo y {folderCount} carpetas"],
    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} archivo y 1 carpeta","{fileCount} archivos y 1 carpeta","{fileCount} archivos y 1 carpeta"],
    "{fileCount} files and {folderCount} folders" : "{fileCount} archivos y {folderCount} carpetas",
    "List of favorites files and folders." : "Lista de archivos y carpetas favoritos.",
    "No favorites yet" : "Aún no hay favoritos",
    "Files and folders you mark as favorite will show up here" : "Aquí aparecerán los archivos y carpetas que has marcado como favoritos",
    "All files" : "Todos los archivos",
    "List of your files and folders." : "Lista de sus archivos y carpetas.",
    "Personal Files" : "Archivos Personales",
    "List of your files and folders that are not shared." : "Lista de sus archivos y carpetas que no están compartidos.",
    "No personal files found" : "No se encontraron archivos personales",
    "Files that are not shared will show up here." : "Los archivos y carpetas que no ha compartido aparecerán aquí.",
    "List of recently modified files and folders." : "Lista de archivos y carpetas modificados recientemente.",
    "No recently modified files" : "No hay archivos modificados recientemente.",
    "Files and folders you recently modified will show up here." : "Los archivos y carpetas que ha modificado recientemente aparecerán aquí.",
    "No entries found in this folder" : "No hay entradas en esta carpeta",
    "Select all" : "Seleccionar todo",
    "Upload too large" : "Subida demasido grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los archivos que está intentando subir sobrepasan el tamaño máximo permitido en este servidor.",
    "Text file" : "Archivo de texto",
    "New text file.txt" : "Nuevo archivo.txt",
    "Direct link was copied (only works for users who have access to this file/folder)" : "El enlace directo fue copiado (solo funciona para usuarios que tienen acceso a este archivo/carpeta)",
    "Copy direct link (only works for users who have access to this file/folder)" : "Copiar enlace directo (solo funciona para usuarios que tienen acceso a este archivo/carpeta)",
    "You can only favorite a single file or folder at a time" : "Solo puedes marcar como favorito un solo archivo o carpeta cada vez",
    "\"remote user\"" : "\"usuario remoto\"",
    "Search users" : "Buscar usuarios",
    "You might not have have permissions to view it, ask the sender to share it" : "Puede que no tenga permisos para verlo, solicite al remitente que lo comparta",
    "Set up templates folder" : "Configura una carpeta para plantillas",
    "Toggle %1$s sublist" : "Alternar %1$s sublista",
    "Toggle grid view" : "Alternar vista de cuadrícula",
    "Deleted files" : "Archivos eliminados",
    "Shares" : "Archivos compartidos",
    "Shared with others" : "Compartido con otros",
    "Shared with you" : "Compartido conmigo",
    "Deleted shares" : "Recursos compartidos eliminados",
    "Pending shares" : "Recursos compartidos pendientes",
    "This file has the tag {tag}" : "Este archivo tiene la etiqueta {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Este archivo tiene las etiquetas {firstTags} y {lastTag}",
    "Select the row for {displayName}" : "Seleccione la fila para {displayName}",
    "Open folder {name}" : "Abrir carpeta {name}",
    "Unselect all" : "Desmarcar todos",
    "ascending" : "ascendente",
    "descending" : "descendente",
    "Sort list by {column} ({direction})" : "Ordenar lista por {column} ({direction})",
    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Esta lista no se muestra completamente por motivos de rendimiento. Los archivos se mostrarán a medida que navega por la lista.",
    "Search for an account" : "Buscar una cuenta",
    "Choose" : "Seleccione",
    "No files or folders have been deleted yet" : "No se han borrado archivos o carpetas todavía",
    "Add" : "Añadir",
    "The files is locked" : "El archivo está bloqueado"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
